API Version: 0.0
Library Version: 0.2.0
Generated by gi-docgen 2024.1
enum Talkatu.TagDisplay
An enum representing how a tag should be rendered.
TALKATU_TAG_DISPLAY_INLINE
The tag should be rendered inline.
0
TALKATU_TAG_DISPLAY_BLOCK
The tag should be rendered on its own line.
1
Content